@@ -209,37 +209,13 @@ void AlbumView::OnTrackActivated(QModelIndex trackIndex)
         m_pAlbumTrackView->setEnabled(false); //disable listview temporarily
 
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //show progress indicator
-        setPlayQueue();
+        emit playQueueSet(m_pAlbumBrowser->getTracks(false),m_pAlbumTrackView->currentIndex().row()); //signal that playqueue has been set / updated
+        hide();
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
-
         m_pAlbumTrackView->setEnabled(true); //re-enable the listview
     }
  }
 
-void AlbumView::setPlayQueue()
-{
-    //Set playqueue (i.e., add all tracks from selected track to last track in list to playqueue)
-
-    QList<Spotify::Track*> PlayQueue;
-    Spotify::Track* track;
-
-    for(int pos = m_pAlbumTrackView->currentIndex().row(); pos < m_pAlbumTrackModel->rowCount(); pos++)
-    {
-        int trackPos = m_pAlbumTrackModel->item(pos)->data(ListViewDelegate::customDataRole).toInt();
-         if(m_pAlbumBrowser && trackPos!=-1) //track from playlist
-        {
-             track = m_pAlbumBrowser->getTrack(trackPos);
-             if(track)
-             {
-                 if(track->isAvailable()) //only add track if it is available (playable)
-                     PlayQueue.append(track);
-             }
-         }
-    }
-
-    emit playQueueSet(PlayQueue); //signal that playqueue has been set / updated
-    hide();
-}
 
 void AlbumView::OnAlbumCoverLoaded()
 {
