@@ -72,8 +72,6 @@ private:
 
     void addTracks(); //add tracks to listview
 
-    void setPlayQueue(); //assign playqueue
-
 private slots:
 
     void OnAlbumBrowserReady(Spotify::AlbumBrowser* browser, qint32 callerID);
@@ -83,7 +81,7 @@ private slots:
 
 signals:
 
-    void playQueueSet(const QList<Spotify::Track*>&); //signal emitted when user selects track from album list, and new play queue is
+    void playQueueSet(const QList<Spotify::Track*>&, qint32); //signal emitted when user selects track from album list, and new play queue is
                                                       //set
 
 };
