@@ -11,12 +11,14 @@ void CListView::keyPressEvent(QKeyEvent *evt)
  {
      //Overriden keypress handler (ignores events from left / right arrow keys).
 
-    if(evt->key()==Qt::Key_Left||evt->key()==Qt::Key_Right)
+    if(evt->key()==Qt::Key_Left||evt->key()==Qt::Key_Right||evt->key()==Qt::Key_M)
     {
         evt->ignore();
     }
-
-    QListView::keyPressEvent(evt); //default handler
+    else
+    {
+        QListView::keyPressEvent(evt); //default handler
+    }
 
  }
 
