@@ -8,7 +8,10 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* pa
 {
     //construct the Queue View UI
 
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow); //window is part of window stack
+   // setAttribute(Qt::WA_Maemo5AutoOrientation); //display auto-rotation
+#endif
 
     setWindowTitle(tr("Now Playing"));
 
@@ -35,7 +38,8 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* pa
     m_shuffleStateChanged = false;
 
     //define slider used for displaying buffering and track progress
-    m_pProgressSlider = new CustomSlider(this,SLIDER_WIDTH,SLIDER_HEIGHT);
+    m_currSliderWidth = SLIDER_WIDTH_LANDSCAPE;
+    m_pProgressSlider = new CustomSlider(this,m_currSliderWidth,SLIDER_HEIGHT);
     m_pProgressSlider->setBgColor(QColor(51,51,51)); //background color of progress slider
     m_pProgressSlider->setP1Color(QColor(8,117,189)); //color of buffering progress bar
     m_pProgressSlider->setP2Color(QColor(41,166,241)); //color of track progress bar
@@ -75,8 +79,9 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* pa
     connect(&m_PrevBtn,SIGNAL(clicked()),SLOT(OnPrevTrackBtn()));
     connect(&m_NextBtn,SIGNAL(clicked()),SLOT(OnNextTrackBtn()));
     connect(menuBar(),SIGNAL(triggered(QAction*)),SLOT(OnMenubarAction(QAction*)));
+    //connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
 
-    m_AlbumCover.setFixedSize(QUEUEVIEW_COVERART_WIDTH,QUEUEVIEW_COVERART_HEIGHT); //set fixed size of the album coverart
+    m_AlbumCover.setFixedSize(QUEUEVIEW_COVERART_WIDTH_LANDSCAPE,QUEUEVIEW_COVERART_HEIGHT_LANDSCAPE); //set fixed size of the album coverart
 
     //style the player control buttons
     m_PauseResumeBtn.setCheckable(true); //toggle button (between pause / resume states)
@@ -109,28 +114,43 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* pa
             "QPushButton {background-image: url(/usr/share/images/shuffle.png);}"
             "QPushButton:on {background-image: url(/usr/share/images/shuffle-down.png);}");
 
-    //sub-layout containing player controls, progress slider and spectrum analyzer
-    m_PlayControls.setSpacing(0);
-    m_PlayControls.addWidget(&m_PrevBtn,0,0,1,1,Qt::AlignRight);
-    m_PlayControls.addWidget(&m_PauseResumeBtn,0,1,1,1,Qt::AlignLeft);
-    m_PlayControls.addWidget(&m_NextBtn,0,2,Qt::AlignLeft);
-    m_PlayControls.setColumnStretch(2,6);
-    m_PlayControls.addWidget(&m_ShuffleBtn,0,3,1,1,Qt::AlignLeft);
-    m_PlayControls.setColumnStretch(3,5);
-    m_PlayControls.addWidget(m_pProgressSlider,0,4,1,1);
-    m_PlayControls.setColumnMinimumWidth(4,370);
-    m_PlayControls.setColumnStretch(4,10);
-    m_PlayControls.addWidget(m_pSpectrum,0,5,1,1,Qt::AlignRight);
-    m_PlayControls.setContentsMargins(10,5,10,0);
+    m_pPlayerControlsHoriz = new QGridLayout();
 
+    m_pPlayerControlsHoriz->setSpacing(0);
+    m_pPlayerControlsHoriz->addWidget(&m_PrevBtn,0,0,1,1,Qt::AlignRight);
+    m_pPlayerControlsHoriz->addWidget(&m_PauseResumeBtn,0,1,1,1,Qt::AlignLeft);
+    m_pPlayerControlsHoriz->addWidget(&m_NextBtn,0,2,Qt::AlignLeft);
+    m_pPlayerControlsHoriz->setColumnStretch(2,6);
+    m_pPlayerControlsHoriz->addWidget(&m_ShuffleBtn,0,3,1,1,Qt::AlignLeft);
+    m_pPlayerControlsHoriz->setColumnStretch(3,5);
+    m_pPlayerControlsHoriz->addWidget(m_pProgressSlider,0,4,1,1);
+    m_pPlayerControlsHoriz->setColumnMinimumWidth(4,370);
+    m_pPlayerControlsHoriz->setColumnStretch(4,10);
+    m_pPlayerControlsHoriz->addWidget(m_pSpectrum,0,5,1,1,Qt::AlignRight);
+    m_pPlayerControlsHoriz->setContentsMargins(10,5,10,0);
 
-    //set up the QueueView UI layout
-    m_GridLayout.addWidget(&m_AlbumCover,0,0,7,1,Qt::AlignTop);
-    m_GridLayout.addWidget(m_pTrackInfoView,0,1,7,1);
-    m_GridLayout.addLayout(&m_PlayControls,7,0,1,-1);
-    m_GridLayout.setContentsMargins(0,5,0,10); //set layout margin
+    m_pHorizGridLayout = new QGridLayout();
 
-    m_MainLayout.setLayout(&m_GridLayout);
+    //set up the QueueView UI landscape mode layout
+
+    m_pHorizGridLayout->addWidget(&m_AlbumCover,0,0,7,1,Qt::AlignTop);
+    m_pHorizGridLayout->addWidget(m_pTrackInfoView,0,1,7,1);
+    m_pHorizGridLayout->addLayout(m_pPlayerControlsHoriz,7,0,1,-1);
+    m_pHorizGridLayout->setContentsMargins(0,5,0,10); //set layout margin
+
+    m_pPlayerControlsVert = new QGridLayout();
+    m_pProgressLayoutVert = new QGridLayout();
+
+    //allocate the QueueView UI portrait mode layout
+    m_pVertLayout = new QGridLayout();
+    m_pVertLayout->addLayout(m_pPlayerControlsVert,2,0,1,-1);
+    m_pVertLayout->addLayout(m_pProgressLayoutVert,3,0,1,-1);
+
+    m_MainHorizLayout.setLayout(m_pHorizGridLayout);
+    m_MainVertLayout.setLayout(m_pVertLayout);
+
+    m_MainLayout.addWidget(&m_MainHorizLayout); //assign landscape mode grid layout
+    m_MainLayout.addWidget(&m_MainVertLayout); //add portrait mode layoyt
 
     setCentralWidget(&m_MainLayout);
 }
@@ -201,6 +221,7 @@ void QueueView::setListViewState()
         index = m_pTrackInfoModel->index(m_currQueuePos,0);
         if(index.isValid())
         {
+            m_pTrackInfoView->scrollTo(index,QAbstractItemView::PositionAtTop); //center the current item at the top of viewport
             m_pTrackInfoView->setCurrentIndex(index); //set the current row in the queue list
         }
     }
@@ -222,9 +243,10 @@ void QueueView::OnPlaybackStateChangeRequest(enum pb_state_e requestedState)
     }
 }
 
-void QueueView::setQueueInitialState(QList<Spotify::Track*> queue)
+void QueueView::setQueueInitialState(QList<Spotify::Track*> queue, qint32 currQueuePos)
 {
     //set the initial state of the play queue view (assign new playqueue, reset members etc.)
+    //Param. currQueuePos specifies the current position within the playqueue.
 
     m_PlayQueue = queue;
 
@@ -232,8 +254,8 @@ void QueueView::setQueueInitialState(QList<Spotify::Track*> queue)
 
     //set the queue initial state
 
-    m_currQueuePos = 0; //initial playback pos
-    m_currQueueBuffPos = 0; //initial buffering track pos
+    m_currQueuePos = currQueuePos; //initial playback pos
+    m_currQueueBuffPos = currQueuePos; //initial buffering track pos
     m_shuffleStateChanged = false;
     m_currTrackScrobbled = false;
 
@@ -467,16 +489,6 @@ void QueueView::playTrack(Spotify::Track* track)
     m_pProgressSlider->setPos1(0);
     m_pProgressSlider->setPos2(0);
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
-    strTrack = track->getName();
-    if(track->getArtist())
-        strArtist = track->getArtist()->getName();
-    if(track->getAlbum())
-    {
-        strAlbum = track->getAlbum()->getName();
-        if(track->getAlbum()->getArtist())
-            strAlbumArtist = track->getAlbum()->getArtist()->getName();
-    }
-    emit updateNowPlaying(strTrack,strArtist,strAlbum,strAlbumArtist); //send update now playing request to Last.fm
     QMaemo5InformationBox::information(this,tr("Buffering"));
     error = m_pSession->play(track); //request to start playback of track
     if(error.isError())
@@ -487,6 +499,16 @@ void QueueView::playTrack(Spotify::Track* track)
     { //set state of pause / resume button
         m_PauseResumeBtn.setChecked(true);
         m_PauseResumeBtn.setEnabled(true);
+        strTrack = track->getName();
+        if(track->getArtist())
+            strArtist = track->getArtist()->getName();
+        if(track->getAlbum())
+        {
+            strAlbum = track->getAlbum()->getName();
+            if(track->getAlbum()->getArtist())
+                strAlbumArtist = track->getAlbum()->getArtist()->getName();
+        }
+        emit updateNowPlaying(strTrack,strArtist,strAlbum,strAlbumArtist); //send update now playing request to Last.fm
     }
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
 }
@@ -498,11 +520,11 @@ void QueueView::OnTrackBufferedAmountUpdated(qint32 bufferedAmount)
 
     if(m_currQueuePos != m_currQueueBuffPos)
     {
-        currPos = SLIDER_WIDTH; //current track has been completely buffered
+        currPos = m_currSliderWidth; //current track has been completely buffered
     }
     else
     {
-        currPos = (bufferedAmount*SLIDER_WIDTH) / (m_currTrackDuration*1000); //current track has partly been buffered
+        currPos = (bufferedAmount*m_currSliderWidth) / (m_currTrackDuration*1000); //current track has partly been buffered
     }
 
     m_pProgressSlider->setPos1(currPos); //set curr. slider position
@@ -540,7 +562,7 @@ void QueueView::OnPlaybackPositionUpdated(qint64 playbackPos)
         m_pProgressSlider->setText(strCurrTrackProgressInfo);
     }
 
-    int currPos = (playbackPos*SLIDER_WIDTH) / (m_currTrackDuration*1000);
+    int currPos = (playbackPos*m_currSliderWidth) / (m_currTrackDuration*1000);
 
     m_pProgressSlider->setPos2(currPos); //set curr. slider position
 }
@@ -746,7 +768,7 @@ void QueueView::OnTrackPlaybackFinished()
             { //track pre-buffering mode active; reset playback position and playing state
                 m_pSession->setPlaybackPos(0); //reset current playback position
                 if(m_currQueueBuffPos==-1)
-                    m_pProgressSlider->setPos1(SLIDER_WIDTH); //set buffering progress to 100% (final track buffered completely)
+                    m_pProgressSlider->setPos1(m_currSliderWidth); //set buffering progress to 100% (final track buffered completely)
                 if(m_currQueueBuffPos != oldQueuePos)
                 {
                     if(m_shuffleStateChanged)
@@ -780,7 +802,7 @@ void QueueView::OnAlbumCoverLoaded()
     //assign it to the album coverart container.
 
     if(m_pAlbumCoverContainer)
-        m_AlbumCover.setPixmap(QPixmap::fromImage(m_pAlbumCoverContainer->getImage()).scaled(QUEUEVIEW_COVERART_WIDTH,QUEUEVIEW_COVERART_HEIGHT));
+        m_AlbumCover.setPixmap(QPixmap::fromImage(m_pAlbumCoverContainer->getImage()).scaled(QUEUEVIEW_COVERART_WIDTH_LANDSCAPE,QUEUEVIEW_COVERART_HEIGHT_LANDSCAPE));
 }
 
 void QueueView::OnShuffleToggle()
@@ -889,7 +911,7 @@ void QueueView::OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 caller
                     QMaemo5InformationBox::information(this,tr("Failed to load tracks!"));
                 }
                 browser->sortByDiscIndex(); //sort tracks in album order
-                emit playQueueSet(browser->getTracks(false)); //only add available (playable) album tracks to the playqueue
+                emit playQueueSet(browser->getTracks(false),0); //only add available (playable) album tracks to the playqueue
                 setListViewState();
             }
         }
@@ -927,3 +949,66 @@ void QueueView::OnViewArtistAction()
         }
     }
 }
+
+void QueueView::OnOrientationChanged()
+{
+    //Device orientation changed (display rotation) notification
+
+    QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
+    if (screenGeometry.width() > screenGeometry.height())
+    {
+        //switch to landscape mode
+        m_pVertLayout->removeWidget(&m_AlbumCover);
+        m_pVertLayout->removeWidget(m_pTrackInfoView);
+        m_pPlayerControlsVert->removeWidget(&m_PrevBtn);
+        m_pPlayerControlsVert->removeWidget(&m_PauseResumeBtn);
+        m_pPlayerControlsVert->removeWidget(&m_NextBtn);
+        m_pPlayerControlsVert->removeWidget(&m_ShuffleBtn);
+        m_pPlayerControlsVert->removeWidget(m_pSpectrum);
+        m_pProgressLayoutVert->removeWidget(m_pProgressSlider);
+
+        m_pHorizGridLayout->addWidget(&m_AlbumCover,0,0,7,1,Qt::AlignTop);
+        m_pHorizGridLayout->addWidget(m_pTrackInfoView,0,1,7,1);
+        m_pPlayerControlsHoriz->setSpacing(0);
+        m_pPlayerControlsHoriz->addWidget(&m_PrevBtn,0,0,1,1,Qt::AlignRight);
+        m_pPlayerControlsHoriz->addWidget(&m_PauseResumeBtn,0,1,1,1,Qt::AlignLeft);
+        m_pPlayerControlsHoriz->addWidget(&m_NextBtn,0,2,Qt::AlignLeft);
+        m_pPlayerControlsHoriz->setColumnStretch(2,6);
+        m_pPlayerControlsHoriz->addWidget(&m_ShuffleBtn,0,3,1,1,Qt::AlignLeft);
+        m_pPlayerControlsHoriz->setColumnStretch(3,5);
+        m_pPlayerControlsHoriz->addWidget(m_pProgressSlider,0,4,1,1);
+        m_currSliderWidth = SLIDER_WIDTH_LANDSCAPE;
+        m_pProgressSlider->setSize(m_currSliderWidth,SLIDER_HEIGHT);
+        m_pPlayerControlsHoriz->setColumnMinimumWidth(4,370);
+        m_pPlayerControlsHoriz->setColumnStretch(4,10);
+        m_pPlayerControlsHoriz->addWidget(m_pSpectrum,0,5,1,1,Qt::AlignRight);
+        m_MainLayout.setCurrentIndex(LANDSCAPE_ORIENTATION); //active landscape layout
+    }
+    else
+    {
+        //switch to portrait mode
+        m_pHorizGridLayout->removeWidget(&m_AlbumCover);
+        m_pHorizGridLayout->removeWidget(m_pTrackInfoView);
+        m_pPlayerControlsHoriz->removeWidget(&m_PrevBtn);
+        m_pPlayerControlsHoriz->removeWidget(&m_PauseResumeBtn);
+        m_pPlayerControlsHoriz->removeWidget(&m_NextBtn);
+        m_pPlayerControlsHoriz->removeWidget(&m_ShuffleBtn);
+        m_pPlayerControlsHoriz->removeWidget(m_pProgressSlider);
+        m_pPlayerControlsHoriz->removeWidget(m_pSpectrum);
+
+        m_pVertLayout->addWidget(&m_AlbumCover,0,0,1,1,Qt::AlignCenter);
+        m_pVertLayout->addWidget(m_pTrackInfoView,1,0,1,1);
+        m_pPlayerControlsVert->setSpacing(0);
+        m_pPlayerControlsVert->addWidget(&m_PrevBtn,0,0,1,1,Qt::AlignRight);
+        m_pPlayerControlsVert->addWidget(&m_PauseResumeBtn,0,1,1,1,Qt::AlignLeft);
+        m_pPlayerControlsVert->addWidget(&m_NextBtn,0,2,Qt::AlignLeft);
+        m_pPlayerControlsVert->setColumnStretch(2,6);
+        m_pPlayerControlsVert->addWidget(&m_ShuffleBtn,0,3,1,1,Qt::AlignLeft);
+        m_pPlayerControlsVert->setColumnStretch(3,5);
+        m_pPlayerControlsVert->addWidget(m_pSpectrum,0,4,1,1,Qt::AlignRight);
+        m_currSliderWidth = SLIDER_WIDTH_PORTRAIT;
+        m_pProgressSlider->setSize(m_currSliderWidth,SLIDER_HEIGHT);
+        m_pProgressLayoutVert->addWidget(m_pProgressSlider,0,0,1,-1);
+        m_MainLayout.setCurrentIndex(PORTRAIT_ORIENTATION); //activate portrait layout
+    }
+}
