@@ -3,6 +3,7 @@
 #define QUEUEVIEW_H
 
 #include <QtGui/QWidget>
+#include <QtGui/QStackedWidget>
 #include <QtGui/QLabel>
 #include <QtGui/QPushButton>
 #include <QtGui/QImage>
@@ -32,11 +33,16 @@
 
 //defines
 
-#define SLIDER_WIDTH 355 //width of the custom progress slider widget
-#define SLIDER_HEIGHT 40 //height of the custom progress slider widget
+#define LANDSCAPE_ORIENTATION   0
+#define PORTRAIT_ORIENTATION    1
 
-#define QUEUEVIEW_COVERART_WIDTH    355
-#define QUEUEVIEW_COVERART_HEIGHT   355
+#define SLIDER_WIDTH_LANDSCAPE 355 //width of the custom progress slider widget (landscape mode)
+#define SLIDER_HEIGHT 40 //height of the custom progress slider widget
+#define SLIDER_WIDTH_PORTRAIT 440 //width of the custom progress slider widget (portrait mode)
+
+
+#define QUEUEVIEW_COVERART_WIDTH_LANDSCAPE    355
+#define QUEUEVIEW_COVERART_HEIGHT_LANDSCAPE   355
 
 #define QUEUEVIEW_ID 1
 
@@ -49,7 +55,7 @@ public:
     QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* parent = 0); //constructor
     ~QueueView();
 
-    void setQueueInitialState(QList<Spotify::Track*> queue); //public method for setting the initial playqueue view state
+    void setQueueInitialState(QList<Spotify::Track*> queue, qint32 currQueuePos); //public method for setting the initial playqueue view state
 
     virtual void show(); //overriden show method
 
@@ -60,11 +66,21 @@ protected:
 
 private:
 
-    QWidget m_MainLayout;
+    QStackedWidget m_MainLayout; //main landcape and portrait mode container widget
 
-    QGridLayout m_GridLayout;
+    QWidget m_MainHorizLayout;
 
-    QGridLayout m_PlayControls;
+    QWidget m_MainVertLayout;
+
+    QGridLayout *m_pPlayerControlsHoriz; //grid layout for player controls etc (landscape mode).
+
+    QGridLayout *m_pPlayerControlsVert; //grid layout for player controls etc (portrait mode).
+
+    QGridLayout *m_pProgressLayoutVert; //sub-layout used for holding the progress indicator widget in portrait mode
+
+    QGridLayout *m_pHorizGridLayout; //main landscape mode grid layout
+
+    QGridLayout *m_pVertLayout; //main portrait mode grid layout
 
     QLabel m_AlbumCover;
 
@@ -80,6 +96,8 @@ private:
 
     CustomSlider* m_pProgressSlider; //track progress indicator / slider
 
+    qint32 m_currSliderWidth; //current slider width (for i.e., current portrait and landscape mode)
+
     SpectrumAnalyzer* m_pSpectrum; //spectrum (active during audio playback)
 
     QListView* m_pTrackInfoView; //track info listview
@@ -161,6 +179,7 @@ private slots:
     void OnPlayAlbumAction();
     void OnViewArtistAction();
     void OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 callerID);
+    void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
 
 signals:
 
@@ -170,7 +189,7 @@ signals:
     void showArtistView(Spotify::Artist*); //request to show the artist view for the specified artist
     void updateNowPlaying(const QString& strTrackName, const QString& strArtistName, const QString& strAlbumName, const QString& strAlbumArtist); //request to update the client Last.fm 'now playing' status
     void scrobbleTrack(); //request to scrobble current track to Last.fm
-    void playQueueSet(const QList<Spotify::Track*>&); //signal emitted upon new playqueue set
+    void playQueueSet(const QList<Spotify::Track*>&, qint32); //signal emitted upon new playqueue set
 };
 
 #endif // QUEUEVIEW_H
