@@ -14,7 +14,8 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     setFixedSize(800,468);
 
     //connect signals/slots
-    connect(&this->m_SaveSettingsBtn,SIGNAL(clicked()),SLOT(OnSaveSettingsBtn()));
+    connect(&m_SaveSettingsBtn,SIGNAL(clicked()),SLOT(OnSaveSettingsBtn()));
+    connect(&m_EnableScrobblingSelection,SIGNAL(stateChanged(int)),SLOT(OnScrobblingStateChanged(int)));
 
     m_maxSearchTracksCaption.setText(tr("Max. tracks returned"));
     m_maxSearchTracksInput.setInputMask("9000");
@@ -44,10 +45,26 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_BufferingOptions.setTitle(tr("Buffering settings"));
     m_BufferingOptions.setLayout(&m_BufferingOptionLayout);
 
+    m_EnableScrobblingSelection.setText(tr("Enable scrobbling to Last.fm"));
+    m_LastFMUserIDCaption.setText(tr("Last.fm username"));
+    m_LastFMUserIDInput.setInputMethodHints(Qt::ImhNoAutoUppercase);
+    m_LastFMPasswordCaption.setText(tr("Last.fm password"));
+    m_LastFMPasswordInput.setEchoMode(QLineEdit::Password);
+
+    m_ScrobblingOptionLayout.addWidget(&m_EnableScrobblingSelection,0,0,1,2);
+    m_ScrobblingOptionLayout.addWidget(&m_LastFMUserIDCaption,1,0);
+    m_ScrobblingOptionLayout.addWidget(&m_LastFMUserIDInput,1,1);
+    m_ScrobblingOptionLayout.addWidget(&m_LastFMPasswordCaption,2,0);
+    m_ScrobblingOptionLayout.addWidget(&m_LastFMPasswordInput,2,1);
+
+    m_ScrobblingOptions.setTitle(tr("Scrobbling options"));
+    m_ScrobblingOptions.setLayout(&m_ScrobblingOptionLayout);
+
     m_SaveSettingsBtn.setText(tr("Save"));
 
     m_GridLayout.addWidget(&m_SearchOptions,0,0,1,-1);
     m_GridLayout.addWidget(&m_BufferingOptions,1,0,1,-1);
+    m_GridLayout.addWidget(&m_ScrobblingOptions,2,0,1,-1);
 
     m_MainAreaLayout.setLayout(&m_GridLayout);
     m_MainArea.setWidget(&m_MainAreaLayout);
@@ -91,6 +108,27 @@ void SettingsDialog::readSettings()
             m_PreBufferNextTrackSelection.setChecked(true);
         else
             m_PreBufferNextTrackSelection.setChecked(false);
+
+        m_enableScrobbling = m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt();
+
+        if(m_enableScrobbling)
+        {
+            m_EnableScrobblingSelection.setChecked(true);
+            m_LastFMUserIDInput.setEnabled(true);
+            m_LastFMPasswordInput.setEnabled(true);
+            m_strLastFMUserID = m_pAppSettings->value("QSpot/lastfmUid","").toString();
+            m_strLastFMPassword = m_pAppSettings->value("QSpot/lastfmPwd","").toString();
+            m_LastFMUserIDInput.setText(m_strLastFMUserID);
+            m_LastFMPasswordInput.setText(m_strLastFMPassword);
+        }
+        else
+        {
+            m_EnableScrobblingSelection.setChecked(false);
+            m_LastFMUserIDInput.setEnabled(false);
+            m_LastFMPasswordInput.setEnabled(false);
+            m_LastFMUserIDInput.setText("");
+            m_LastFMPasswordInput.setText("");
+        }
     }
 }
 
@@ -128,22 +166,56 @@ void SettingsDialog::saveSettings()
 
         if(m_PreBufferNextTrackSelection.isChecked() && !m_preBufferingActive)
         {
-            qDebug() << "1";
             m_pAppSettings->setValue("QSpot/preBufferingActive",1);
             settingsChanged = true;
         }
         else if(!m_PreBufferNextTrackSelection.isChecked() && m_preBufferingActive)
         {
-            qDebug() << "0";
             m_pAppSettings->setValue("QSpot/preBufferingActive",0);
             settingsChanged = true;
         }
 
+        if(m_EnableScrobblingSelection.isChecked())
+        {
+            m_pAppSettings->setValue("QSpot/enableScrobbling",1);
+            m_pAppSettings->setValue("QSpot/lastfmUid",m_LastFMUserIDInput.text());
+            m_pAppSettings->setValue("QSpot/lastfmPwd",m_LastFMPasswordInput.text());
+            settingsChanged = true;
+        }
+        else
+        {
+            m_pAppSettings->setValue("QSpot/enableScrobbling",0);
+            //empty associated userID / password values
+            m_pAppSettings->setValue("QSpot/lastfmUid","");
+            m_pAppSettings->setValue("QSpot/lastfmPwd","");
+            settingsChanged = true;
+        }
+
         if(settingsChanged)
             emit settingsSaved();
     }
 }
 
+void SettingsDialog::OnScrobblingStateChanged(int newState)
+{
+    //scrobbling state has been changed (enabled / disabled)
+
+    if(newState==Qt::Checked)
+    {
+        //scrobbling enabled
+        m_LastFMUserIDInput.setEnabled(true);
+        m_LastFMPasswordInput.setEnabled(true);
+    }
+    else
+    {
+        //scrobbling enabled
+        m_LastFMUserIDInput.setEnabled(false);
+        m_LastFMPasswordInput.setEnabled(false);
+        m_LastFMUserIDInput.setText("");
+        m_LastFMPasswordInput.setText("");
+    }
+}
+
 void SettingsDialog::OnSaveSettingsBtn()
 {
     //save current settings (if changed)
