@@ -7,7 +7,9 @@ TrackView::TrackView(Spotify::Session* pSession, QWidget* parent) :
 {
         //constructs the UI track view
 
-        setAttribute(Qt::WA_Maemo5StackedWindow); //set flag that window is part of window stack
+#ifdef Q_WS_MAEMO_5
+        setAttribute(Qt::WA_Maemo5StackedWindow); //window is part of window stack
+#endif
 
         m_pSession = pSession; //set the Spotify session instance
         connect(m_pSession,SIGNAL(albumBrowserReady(Spotify::AlbumBrowser*,qint32)),SLOT(OnAlbumBrowseReady(Spotify::AlbumBrowser*,qint32)));
@@ -157,7 +159,7 @@ void TrackView::OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 caller
                     QMaemo5InformationBox::information(this,tr("Failed to load tracks!"));
                 }
                 browser->sortByDiscIndex(); //sort tracks in album order
-                emit playQueueSet(browser->getTracks(false)); //only add available (playable) album tracks to the playqueue
+                emit playQueueSet(browser->getTracks(false),0); //only add available (playable) album tracks to the playqueue
             }
         }
     }
@@ -297,25 +299,27 @@ void TrackView::OnTrackActivated(QModelIndex trackIndex)
 
 void TrackView::setPlayQueue()
 {
-    //Set playqueue (i.e., add all tracks from selected track to last track in list to playqueue)
+    //Assign new playqueue
 
     QList<Spotify::Track*> PlayQueue;
-    Spotify::Track* track;
 
-    for(int pos = m_pTrackListView->currentIndex().row(); pos < m_pTrackListModel->rowCount(); pos++)
+    if(m_pPlaylist) //playlist view
     {
-        int trackPos = m_pTrackListModel->item(pos)->data(Qt::UserRole).toInt();
-         if(m_pPlaylist) //track from playlist
-             track = m_pPlaylist->getTrack(trackPos);
-         else //search result etc.
-             track = m_TrackList.at(trackPos);
-         if(track)
-         {
-             PlayQueue.append(track);
-         }
+        PlayQueue = m_pPlaylist->getTracks(false);
+        emit playQueueSet(PlayQueue,m_pTrackListView->currentIndex().row()); //signal that playqueue has been set / updated
+    }
+    else //search results view
+    { //add all tracks including (and following) the selected track for search results
+        for(int pos = m_pTrackListView->currentIndex().row(); pos < m_pTrackListModel->rowCount(); pos++)
+        {
+            Spotify::Track* track = m_TrackList.at(pos);
+            if(track)
+            {
+                PlayQueue.append(track);
+            }
+        }
+        emit playQueueSet(PlayQueue,0); //signal that playqueue has been set / updated
     }
-
-    emit playQueueSet(PlayQueue); //signal that playqueue has been set / updated
 }
 
 
