@@ -107,7 +107,7 @@ private slots:
 
 signals:
 
-    void playQueueSet(const QList<Spotify::Track*>&); //signal emitted upon new playqueue set
+    void playQueueSet(const QList<Spotify::Track*>&, qint32); //signal emitted upon new playqueue set
     void showFMTransmitterDialog(); //signal emitted upon request to show the FM Transmitter control panel dialog (plugin)
     void showAlbumView(Spotify::Album*); //request to show the album view for the specified album
     void showArtistView(Spotify::Artist*); //request to show the artist view for the specified artist
