@@ -7,8 +7,6 @@ ArtistView::ArtistView(Spotify::Session* pSession, QWidget* pParent)
 {
     // set up the view UI etc
 
-   // setAttribute(Qt::WA_Maemo5StackedWindow); //set flag that window is part of window stack
-
     m_pSession = pSession;
 
     setWindowTitle(tr("Browse Artist"));
@@ -124,6 +122,39 @@ void ArtistView::OnArtistCatalogueReady(Spotify::ArtistCatalogue* pArtistCatalog
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
 }
 
+QList<Spotify::Album*> ArtistView::sortArtistAlbums()
+ {
+     //Arranges to albums returned by the artist browse request in desired order for listview.
+     //Assigns all albums with artist matching with the browsed artist to the Albums category,
+    // and all other albums to the Other (Appears on) category.
+     //Returns the sorted list.
+
+    QList<Spotify::Album*> albums;
+    Spotify::Album* pAlbum = NULL;
+
+    for(int pos = 0; pos < m_pArtistCatalogue->getAlbums()->size(); pos++)
+    {
+        pAlbum = m_pArtistCatalogue->getAlbums()->at(pos);
+        if(pAlbum)
+        {
+            if(pAlbum->isAvailable())
+            {
+              if(pAlbum->getArtist()->getArtist()==m_pArtistCatalogue->getArtist()->getArtist())
+                {
+                  pAlbum->setType(Spotify::Album::ALBUM); //Album
+                }
+                else
+                {
+                  pAlbum->setType(Spotify::Album::UNKNOWN); //Appears on
+                }
+                albums.append(pAlbum);
+            }
+        }
+    }
+
+    return albums;
+ }
+
 void ArtistView::addAlbums()
 {
     //add artist albums to the listview
@@ -136,11 +167,13 @@ void ArtistView::addAlbums()
 
     int currAlbumType = -1;
 
-    qSort(m_pArtistCatalogue->getAlbums()->begin(),m_pArtistCatalogue->getAlbums()->end(),albumsByTypeYearDesc); //sort albums first by type, then by year
+    m_ArtistAlbums = sortArtistAlbums(); //do prelimimary sorting
 
-    for(int pos = 0; pos < m_pArtistCatalogue->getAlbums()->size(); pos++)
+    qSort(m_ArtistAlbums.begin(),m_ArtistAlbums.end(),albumsByTypeYearDesc); //sort albums first by type, then by year
+
+    for(int pos = 0; pos < m_ArtistAlbums.size(); pos++)
     {
-        Spotify::Album* currAlbum = m_pArtistCatalogue->getAlbums()->at(pos);
+        Spotify::Album* currAlbum = m_ArtistAlbums.at(pos);
         if(currAlbum)
         {
             if(currAlbum->isAvailable())
@@ -185,7 +218,7 @@ void ArtistView::addAlbums()
 void ArtistView::OnAlbumActivated(QModelIndex albumIndex)
 {
     //an album has been activated (selected) from the listview
-   Spotify::Album* pAlbum = m_pArtistCatalogue->getAlbums()->at(albumIndex.data(ListViewDelegate::customDataRole).toInt());
+   Spotify::Album* pAlbum = m_ArtistAlbums.at(albumIndex.data(ListViewDelegate::customDataRole).toInt());
 
    if(pAlbum)
    {
