@@ -3,7 +3,11 @@
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent)
 {
-    setAttribute(Qt::WA_Maemo5StackedWindow);
+
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5StackedWindow); //window is part of window stack
+   // setAttribute(Qt::WA_Maemo5AutoOrientation);
+#endif
 
     QCoreApplication::setApplicationName("QSpot"); //Setup app name
     QCoreApplication::setApplicationVersion(APP_VERSION);
@@ -50,17 +54,17 @@ MainWindow::MainWindow(QWidget *parent)
     initAboutDialog();
 
     m_pTrackView = new TrackView(m_pSession,this);
-    connect(m_pTrackView,SIGNAL(playQueueSet(const QList<Spotify::Track*>&)),SLOT(OnSetPlayQueue(const QList<Spotify::Track*>&)));
+    connect(m_pTrackView,SIGNAL(playQueueSet(const QList<Spotify::Track*>&,qint32)),SLOT(OnSetPlayQueue(const QList<Spotify::Track*>&,qint32)));
     connect(m_pTrackView,SIGNAL(showFMTransmitterDialog()),SLOT(OnDisplayFMTransmitterDialog()));
     connect(m_pTrackView,SIGNAL(showAlbumView(Spotify::Album*)),SLOT(OnShowAlbumView(Spotify::Album*)));
     connect(m_pTrackView,SIGNAL(showArtistView(Spotify::Artist*)),SLOT(OnShowArtistView(Spotify::Artist*)));
 
     m_pAlbumView = new AlbumView(m_pSession,m_pTrackView);
-    connect(m_pAlbumView,SIGNAL(playQueueSet(const QList<Spotify::Track*>&)),SLOT(OnSetPlayQueue(const QList<Spotify::Track*>&)));
+    connect(m_pAlbumView,SIGNAL(playQueueSet(const QList<Spotify::Track*>&,qint32)),SLOT(OnSetPlayQueue(const QList<Spotify::Track*>&,qint32)));
 
     m_pQueueView = new QueueView(m_pSession,m_pOssoWrapper,this); //initial parent set to current instance
     connect(m_pQueueView,SIGNAL(playQueuePosUpdated(qint32)),SLOT(OnPlayQueuePosUpdated(qint32)));
-    connect(m_pQueueView,SIGNAL(playQueueSet(QList<Spotify::Track*>)),SLOT(OnSetPlayQueue(QList<Spotify::Track*>)));
+    connect(m_pQueueView,SIGNAL(playQueueSet(QList<Spotify::Track*>,qint32)),SLOT(OnSetPlayQueue(QList<Spotify::Track*>,qint32)));
     connect(m_pQueueView,SIGNAL(showFMTransmitterDialog()),SLOT(OnDisplayFMTransmitterDialog()));
     connect(m_pQueueView,SIGNAL(showAlbumView(Spotify::Album*)),SLOT(OnShowAlbumView(Spotify::Album*)));
     connect(m_pQueueView,SIGNAL(showArtistView(Spotify::Artist*)),SLOT(OnShowArtistView(Spotify::Artist*)));
@@ -272,11 +276,12 @@ void MainWindow::OnNowPlaying()
     }
 }
 
-void MainWindow::OnSetPlayQueue(const QList<Spotify::Track*>& queue)
+void MainWindow::OnSetPlayQueue(const QList<Spotify::Track*>& queue, qint32 currQueuePos)
 {
-    //set the current (active) playqueue to be
+    //set the current (active) playqueue, and associated playback position within the queue.
     m_PlayQueue = queue;
-    m_pQueueView->setQueueInitialState(m_PlayQueue);
+    m_currQueuePos = currQueuePos;
+    m_pQueueView->setQueueInitialState(m_PlayQueue, currQueuePos);
     if(m_pArtistView->isVisible())
         m_pArtistView->hide();
     m_pQueueView->show();
@@ -409,10 +414,6 @@ void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
        m_pPlaylistModel->appendRow(item);
    }
 
-   m_SearchInput.setDisabled(false);
-   m_SearchInput.setFocus(); //set initial (default) focus to the Search input field
-   m_SearchBtn.setDisabled(false);
-
    setupInitialState();
 
    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
@@ -425,14 +426,19 @@ void MainWindow::setupInitialState()
     if(!m_AudioInit)
     {
        m_pSession->initAudio(); //init audio interface
-       m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
        m_AudioInit = true;
-       if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt())
-       {
-           //scrobbling enabled, authenticate user to retrieve session key
-           m_pLastFMScrobbler->setCache(true); //enable caching of scrobbles
-           m_pLastFMScrobbler->authenticateSession(m_pAppSettings->value("QSpot/lastfmUid","").toString(),m_pAppSettings->value("QSpot/lastfmPwd","").toString());
-       }
+    }
+
+    m_SearchInput.setDisabled(false);
+    m_SearchInput.setFocus(); //set initial (default) focus to the Search input field
+    m_SearchBtn.setDisabled(false);
+
+    m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
+    if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt())
+    {
+        //scrobbling enabled, authenticate user to retrieve session key
+        m_pLastFMScrobbler->setCache(true); //enable caching of scrobbles
+        m_pLastFMScrobbler->authenticateSession(m_pAppSettings->value("QSpot/lastfmUid","").toString(),m_pAppSettings->value("QSpot/lastfmPwd","").toString());
     }
 
 }
