@@ -39,7 +39,7 @@
 
 //defines
 
-#define APP_VERSION "0.2.0-3" //application version string
+#define APP_VERSION "0.2.1-1" //application version string
 
 #define PLAYLIST_LOADING_TIMEOUT  30 //timeout before giving up on waiting for playlists to load (in seconds)
 
@@ -139,7 +139,7 @@ private slots:
      void OnLoginDialogRejected();
      void OnMainMenuAction(QAction* action);
      void OnPlayingState(bool state);
-     void OnSetPlayQueue(const QList<Spotify::Track*>& queue);
+     void OnSetPlayQueue(const QList<Spotify::Track*>& queue, qint32 currQueuePos);
      void OnPlayQueuePosUpdated(qint32 pos);
      void OnNowPlaying();
      void OnSearch();
