@@ -37,7 +37,8 @@ PlaybackThread::PlaybackThread(QObject* parent)
 
     m_pAudioStream = NULL;
 
-    buffer.maxlength = pa_usec_to_bytes(750000, &ss);
+    //buffer.maxlength = pa_usec_to_bytes(750000, &ss);
+    buffer.maxlength = -1;
     buffer.tlength = -1;
     buffer.prebuf = -1;
     buffer.minreq = -1;
