@@ -144,9 +144,9 @@ namespace Spotify
             Spotify::Error pause();
 
             /**
-             * Toggle playback pause (e.g, stop / continue writing data to PulseAudio).
+             * Toggle playback pause / resume (e.g, stop / continue writing data to PulseAudio).
              */
-            void pausePlayback();
+            void pauseResumePlayback();
 
 
             /**
@@ -157,13 +157,14 @@ namespace Spotify
                                    const int albumOffset,const int albumCount, const int artistOffset,
                                    const int artistCount, void* userData );
 
+
             /**
-             * Get cover art for a given album.
-             * @param album Album to get cover art for.
-             * @param pCallerID Pointer to caller identifier (used to identify ID of receiver of result).
-             * @return Error
+             * Request to load image (identified by imageID) from the Spotify backend
+             * @param imageID ID of the image to be loaded.
+             * @param Pointer to Spotify::ImageContainer instance for storing the loaded image
+             * @return Spotify::Error
              */
-            Spotify::Error getAlbumCover( Spotify::Album* album, qint32* pCallerID);
+            Spotify::Error loadImage(const byte* imageID, Spotify::ImageContainer* pContainer);
 
             /**
              * Get the collection of playlists.
@@ -208,9 +209,9 @@ namespace Spotify
             /**
              * Browse an artist.
              * @param artist Artist to be browsed. The artist metadata does not have to be loaded.
-             * @return Error code.
+             * @return TRUE on success, otherwise FALSE
              */
-            Spotify::Error browse( Spotify::Artist* artist );
+            bool browse( Spotify::Artist* artist );
 
             /**
              * Browse an album
@@ -313,6 +314,7 @@ namespace Spotify
             void OnMusicDelivery(int num_frames, const sp_audioformat* format, QByteArray buffer);
             void OnSearchComplete(sp_search* search);
             void OnAlbumBrowserReady(sp_albumbrowse* ab, qint32*);
+            void OnArtistBrowseComplete( sp_artistbrowse* ab );
             void OnResumeBuffering();
             void OnPlaybackPositionUpdated(qint64 duration);
             void OnPlaybackFinished();
@@ -474,6 +476,8 @@ namespace Spotify
 
             void onAlbumBrowserReady(sp_albumbrowse*, qint32*);
 
+            void onArtistBrowseComplete(sp_artistbrowse*);
+
             void bufferNextTrack();
 
 
